import * as vite from "vite";
import npath from "path";
import { pathToFileURL } from "url";
async function createViteLoader(root) {
  const viteServer = await vite.createServer({
    server: { middlewareMode: true, hmr: false },
    optimizeDeps: { entries: [] },
    clearScreen: false,
    appType: "custom",
    ssr: {
      external: ["@astrojs/tailwind", "@astrojs/mdx", "@astrojs/react"]
    }
  });
  return {
    root,
    viteServer
  };
}
async function tryLoadWith(root, paths, cb) {
  for (const path of paths) {
    const file = npath.join(root, path);
    try {
      const config = await cb(file);
      return {
        value: config.default ?? {},
        filePath: file
      };
    } catch {
    }
  }
  return null;
}
async function loadConfigWithVite(root, { mustExist }) {
  let config = await tryLoadWith(root, ["astro.config.mjs", "astro.config.js"], (path) => import(pathToFileURL(path).toString()));
  if (config) {
    return config;
  }
  const loader = await createViteLoader(root);
  config = await tryLoadWith(root, [
    "astro.config.ts",
    "astro.config.mts",
    "astro.config.cts"
  ], async (path) => {
    const mod = await loader.viteServer.ssrLoadModule(path);
    await loader.viteServer.close();
    return mod;
  });
  if (config) {
    return config;
  }
  await loader.viteServer.close();
  if (mustExist) {
    throw new Error(`Unable to find a config in ${root}`);
  }
  return {
    value: {},
    filePath: void 0
  };
}
export {
  loadConfigWithVite
};
